<?php

/*
 *  Enable post thumbnails
 *  This feature is used for the tab background images
 *
 */

add_theme_support( 'post-thumbnails' );


/*
 *  Add action to include CSS backgrounds in <head>
 *
 */

add_action( 'wp_head', 'ubuntustudio_tabs_bg' );
function ubuntustudio_tabs_bg( ) {
	global $preload;

	/* Only run the code if we are on front page */
	if( is_front_page( ) ) {
		$tabs = get_posts( 'post_type=studio_tab&orderby=menu_order&order=ASC&numberposts=-1' );
		print '<style type="text/css">';
		foreach( $tabs as $tab ) {
			$feat = get_post_thumbnail_id( $tab->ID );
			$src = wp_get_attachment_image_src( $feat, 'full' );

			if( strlen( $src[0] ) > 0 ) {
				print ".fp-tab-{$tab->ID} { background-image: url({$src[0]}) }";
				$preload[] = $src[0];
			}
		}
		if( $_GET['tab'] ) {
			print ".fp-tab-{$_GET['tab']} { display: block; } ";
		} else {
			print ".fp-tab-order-1 { display: block; }";
		}
		print '</style>';

		if( is_array( $preload ) ) {
			print '<script type="text/javascript">';
			print 'var preload = [';
			foreach( $preload as $p ) {
				print '"' . $p . '", ';
			}
			print '];';
			print '</script>';
		}
	}
}

/*
 *  Add new posttype 'TAB'
 *
 */

add_action( 'init', 'ubuntustudio_init' );

function ubuntustudio_init( ) {
	$x = get_bloginfo( 'stylesheet_directory' );

	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'studio-tabs', $x . "/tabs.js", array( "jquery" ), "0.1" );

	$labels = array(
		'name' => _x( 'Front Page Tabs', 'Post type', 'ubuntustudio' ),
		'singular_name' => _x( 'Tab', 'Post type (singular)', 'ubuntustudio' ),
		'add_new' => _x( 'Add New', 'tab', 'ubuntustudio' ),
		'add_new_item' => __( 'Add New Tab', 'ubuntustudio' ),
		'edit_item' => __( 'Edit Tab', 'ubuntustudio' ),
		'new_item' => __( 'New Tab', 'ubuntustudio' ),
		'view_item' => __( 'View Tab', 'ubuntustudio' ),
		'search_items' => __( 'Search Tabs', 'ubuntustudio' ),
		'not_found' => __( 'No tabs found', 'ubuntustudio' ),
		'not_found_in_trash' => __( 'No tabs found in Trash', 'ubuntustudio' ),
//		'parent_item_colon' => __( 'Main Project', 'ubuntustudio' ),
		'menu_name' => __( 'Front Tabs', 'ubuntustudio' )
	);
	$args = array(
		'labels' => $labels,
		'description' => __( 'Tabs for Ubuntu Studio front page', 'ubuntustudio' ),
		'public' => true,
		'publicly_queryable' => true,
		'exclude_from_search' => true,
		'show_ui' => true,
		'show_in_menu' => true,
		'menu_position' => 4,
		'menu_icon' => null, // add a custom icon?
		'capability_type' => 'post',
		'hierarchical' => false,
		'supports' => array( 'title', 'editor', 'revisions', 'thumbnail', 'page-attributes' ),
	);

	register_post_type( 'studio_tab', $args );
}


/*
 *  Add query var 'tab'
 *
 */

add_filter( 'query_vars', 'ubuntustudio_query_vars' );

function ubuntustudio_query_vars( $vars ) {
#    $vars[] = "us_tab";
    return $vars;
}

?>
